# Changelog

We document all notable changes to this project in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.1]

### Changed

* Synchronize versions for new upload to PyPI.

## [0.1.0]

### Added

* Initial release.

[Unreleased]: https://github.com/puppetlabs/relay-sdk-go/compare/v0.1.1...HEAD
[0.1.1]: https://github.com/puppetlabs/relay-sdk-go/compare/v0.1.0...v0.1.1
[0.1.0]: https://github.com/puppetlabs/relay-sdk-go/compare/775de66c45128d999013fa1143398e98dbd071c7...v0.1.0
